@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,7 +22,8 @@
 #include <WebEngineViewer/NetworkPluginUrlInterceptor>
 #include "kcm_config_plugins_debug.h"
 #include <KLocalizedString>
-namespace {
+namespace
+{
 QString networkUrlInterceptorGroupName()
 {
     return QStringLiteral("networkurlinterceptorgroupname");
